quickly combining things
========================

the getting started guide is based on the :ref:`mini-example`


0. importing all the things we need in the example

  .. literalinclude:: ../examples/mini_example.py
    :lines: 10-20

1. identifying the implementations you want to be able to use
   and giving them a name.

  .. literalinclude:: ../examples/mini_example.py
    :lines: 21-29

2. Declaring a element class and some contextual methods

  .. literalinclude:: ../examples/mini_example.py
    :lines: 31-33, 55

3. registration of the contextual method implementations

  .. literalinclude:: ../examples/mini_example.py
    :lines: 34-54, 57-60

4. bringing it all together

  .. literalinclude:: ../examples/mini_example.py
    :lines: 10-20, 62-
